@@ -26,8 +26,13 @@
 
 #define PACKET_TYPE_RUNCOMMAND QStringLiteral("kdeconnect.runcommand")
 
+#ifdef Q_OS_WIN
+#define COMMAND "cmd"
+#define ARGS "/C"
+#else
 #define COMMAND "/bin/sh"
 #define ARGS "-c"
+#endif
 
 K_PLUGIN_CLASS_WITH_JSON(RunCommandPlugin, "kdeconnect_runcommand.json")
 
@@ -54,11 +59,7 @@ void RunCommandPlugin::receivePacket(const NetworkPacket &np)
         }
         const QJsonObject commandJson = value.toObject();
         qCInfo(KDECONNECT_PLUGIN_RUNCOMMAND) << "Running:" << COMMAND << ARGS << commandJson[QStringLiteral("command")].toString();
-#ifdef Q_OS_WIN
-        QProcess::startDetached(commandJson[QStringLiteral("command")].toString(), QStringList());
-#else
         QProcess::startDetached(QStringLiteral(COMMAND), QStringList{QStringLiteral(ARGS), commandJson[QStringLiteral("command")].toString()});
-#endif
     } else if (np.has(QStringLiteral("setup"))) {
         OpenConfig oc;
         oc.openConfiguration(device()->id(), QStringLiteral("kdeconnect_runcommand"));
